package org.example;

import jpos.JposException;
import jpos.MSR;
import jpos.config.JposEntry;
import jpos.config.JposEntryRegistry;
import jpos.events.DataEvent;
import jpos.events.DataListener;
import jpos.loader.JposServiceLoader;
import sun.awt.windows.WToolkit;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;

public class MainForm {
    private  JTextField txt_product_id;
    private  JTextField txt_vendor_id;
    private  JButton btn_open;
    private  JButton btn_close;
    private  JTextField textField1;
    private  JTextField textField2;
    private  JTextField textField3;
    private  JPanel mainPanel;


    private static final String YX_MSR_SERVICE = "yxMsrService";
    private static JposEntry pos = null;
    private static MSR control = null;
    private static DataListener listener = null;

    public MainForm() {

        //open dev button click handler
        btn_open.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {

                //[1] 注册插件信息(Register JPOS plugin)

                if ( null == pos ) {
                    JposEntryRegistry registry = JposServiceLoader.getManager().getEntryRegistry();
                    pos = ControlsTestHelper.createJposEntry("MSR", YX_MSR_SERVICE, "1.15", YX_MSR_SERVICE);

                    //[2]设置端口属性(set port type information: portType: HID, COM; )
                    pos.addProperty("portType", "HID");
                    int vid = Integer.parseInt(txt_vendor_id.getText(), 16);
                    int pid = Integer.parseInt(txt_product_id.getText(), 16);
                    pos.addProperty("vendorId", vid);   //vendorId (contact supplier to get it)
                    pos.addProperty("productId", pid);  //productId (contact supplier to get it)
                    registry.addJposEntry(pos);
                }

                //[3]创建或打开对应的JPOS对象(Create or Open JPOS MSR object)
                if (null == control )
                    control = new MSR();
                try {
                    control.open(YX_MSR_SERVICE);
                } catch (JposException ex) {
                    ex.printStackTrace();
                    //open MSR control failed, unregister jpos plugin and exit
                    JposEntryRegistry registry = JposServiceLoader.getManager().getEntryRegistry();
                    registry.removeJposEntry(YX_MSR_SERVICE);
                    pos = null;
                    //MSR controller set to null
                    control = null;
                    return;
                }

                //[4]注册监听事件(bind msr swipe card event)
                if ( null == listener ) {
                    listener = new DataListener() {
                        @Override
                        public void dataOccurred(DataEvent dataEvent) {
                            System.out.println("dataOccured ......");
                            try {
                                //[5]触发事件回调用(trigger event,then to show track information)
                                String track1 = new String(control.getTrack1Data());
                                String track2 = new String(control.getTrack2Data());
                                String track3 = new String(control.getTrack3Data());

                                //output data in console
                                System.out.println(track1);
                                System.out.println(track2);
                                System.out.println(track3);

                                //show data in text field
                                textField1.setText(track1);
                                textField2.setText(track2);
                                textField3.setText(track3);

                            } catch (JposException e) {
                                e.printStackTrace();
                            }
                        }
                    };
                    control.addDataListener(listener); //add event listener
                }
            }
        });

        //close dev button click handler
        btn_close.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                //remove event listener
                if (null != listener) {
                    control.removeDataListener(listener);
                    listener = null;
                }

                //close JPOS MSR object
                if ( null != control) {
                    try {
                        control.close();
                    } catch (JposException ex) {
                        ex.printStackTrace();
                    }
                    control = null;
                }

                //unregister jpos plugins
                if ( null != pos ) {
                    JposEntryRegistry registry = JposServiceLoader.getManager().getEntryRegistry();
                    registry.removeJposEntry(YX_MSR_SERVICE);
                    pos = null;
                }
            }
        });
    }



    static class MyJFrame extends JFrame {
        protected void processWindowEvent(WindowEvent e) {
            if (e.getID() == WindowEvent.WINDOW_CLOSING) {

                //remove event listener
                if (null != listener) {
                    control.removeDataListener(listener);
                    listener = null;
                }

                //close JPOS MSR object
                if ( null != control) {
                    try {
                        control.close();
                    } catch (JposException ex) {
                        ex.printStackTrace();
                    }
                    control = null;
                }

                //unregister jpos plugins
                if ( null != pos ) {
                    JposEntryRegistry registry = JposServiceLoader.getManager().getEntryRegistry();
                    registry.removeJposEntry(YX_MSR_SERVICE);
                    pos = null;
                }

                System.exit(0);
            }
        }
    }


    public static void main(String[] args) {
        //set font
        Font font = new Font("System",Font.PLAIN,25);
        UIManager.put("Button.font", font);
        UIManager.put("Label.font", font);
        UIManager.put("TextField.font", font);

        JFrame frame = new MyJFrame();
        frame.setTitle("yiXin");
        frame.setContentPane(new MainForm().mainPanel);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        frame.pack();

        //center window to show
        makeCenter(frame);

        frame.setVisible(true);



    }

    private static void makeCenter(JFrame frame )
    {
        Point pt = frame.getLocation();
        double w = frame.getWidth();
        double h = frame.getHeight();
        Dimension dm = WToolkit.getDefaultToolkit().getScreenSize();
        double screenW = dm.getWidth();
        double screenH = dm.getHeight();
        frame.setBounds((int)((screenW-w)/2), (int)((screenH-h)/2), (int)w, (int)h);
    }


}
